@@ -21,17 +21,17 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
-#ifndef _XMLTRANSFORMERPROC_H_
-#define _XMLTRANSFORMERPROC_H_
+#ifndef XMLTRANSFORMERPROC_H
+#define XMLTRANSFORMERPROC_H
 
 // Qt includes.
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
 
 // KTTS includes.
 #include "filterproc.h"
 
-class KProcess;
+class K3Process;
 
 class XmlTransformerProc : virtual public KttsFilterProc
 {
@@ -41,7 +41,7 @@ public:
     /**
      * Constructor.
      */
-    XmlTransformerProc( QObject *parent, const char *name, const QStringList &args = QStringList() );
+    explicit XmlTransformerProc( QObject *parent, const QVariantList &args);
 
     /**
      * Destructor.
@@ -80,7 +80,7 @@ public:
      * @param appId             The DCOP appId of the application that queued the text.
      *                          Also useful for hints about how to do the filtering.
      */
-    virtual QString convert(const QString& inputText, TalkerCode* talkerCode, const QCString& appId);
+    virtual QString convert(const QString& inputText, TalkerCode* talkerCode, const QString& appId);
 
     /**
      * Convert input.  Runs asynchronously.
@@ -96,7 +96,7 @@ public:
      * program may then call @ref getOutput to retrieve converted text.  Calling
      * program must call @ref ackFinished to acknowledge the conversion.
      */
-    virtual bool asyncConvert(const QString& inputText, TalkerCode* talkerCode, const QCString& appId);
+    virtual bool asyncConvert(const QString& inputText, TalkerCode* talkerCode, const QString& appId);
 
     /**
      * Waits for a previous call to asyncConvert to finish.
@@ -131,9 +131,9 @@ public:
     virtual bool wasModified();
 
 private slots:
-    void slotProcessExited(KProcess*);
-    void slotReceivedStdout(KProcess* proc, char* buffer, int buflen);
-    void slotReceivedStderr(KProcess* proc, char* buffer, int buflen);
+    void slotProcessExited(K3Process*);
+    void slotReceivedStdout(K3Process* proc, char* buffer, int buflen);
+    void slotReceivedStderr(K3Process* proc, char* buffer, int buflen);
 
 private:
     // Process output when xsltproc exits.
@@ -150,7 +150,7 @@ private:
     // Processing state.
     int m_state;
     // xsltproc process.
-    KProcess* m_xsltProc;
+    K3Process* m_xsltProc;
     // Input and Output filenames.
     QString m_inFilename;
     QString m_outFilename;
@@ -164,4 +164,4 @@ private:
     bool m_wasModified;
 };
 
-#endif      // _XMLTRANSFORMERPROC_H_
+#endif      // XMLTRANSFORMERPROC_H
